# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['coscon', 'coscon.toast_staging']

package_data = \
{'': ['*']}

install_requires = \
['astropy>=4,<5',
 'defopt>=6,<7',
 'h5py>=3,<4',
 'healpy>=1,<2',
 'matplotlib>=3,<4',
 'numba>=0.52',
 'numba_quaternion>=0.1,<1',
 'numpy>=1,<2',
 'pandas>=1,<2',
 'plotly>=4,<5',
 'pysm3>=3,<4',
 'pyyaml>=5,<6',
 'schema>=0.7',
 'seaborn>=0.11',
 'tabulate>=0.8,<0.9',
 'toast-cmb>=2,<3',
 'toml>=0.10',
 'yamlloader>=0.5']

extras_require = \
{'docs': ['sphinx>=3.3,<4.0',
          'sphinx-bootstrap-theme',
          'pygments-style-solarized',
          'sphinxcontrib-apidoc'],
 'extras': ['coloredlogs>=14,<16'],
 'mpi': ['mpi4py>=3,<4'],
 'tests': ['coverage',
           'coveralls',
           'flake8',
           'pytest',
           'pytest-cov',
           'pytest-parallel',
           'pytest-mpi']}

entry_points = \
{'console_scripts': ['fits_info = coscon.fits_helper:fits_info_cli',
                     'simmap_planck2018 = coscon.cmb:simmap_planck2018_cli']}

setup_kwargs = {
    'name': 'coscon',
    'version': '0.1.0',
    'description': 'Some convenience functions for Cosmology-related analysis.',
    'long_description': '.. This is auto-generated from `docs/README.md`. Do not edit this file directly.\n\n=========================================================\nSome convenience functions for Cosmology-related analysis\n=========================================================\n\n:Date:   March 18, 2021\n\n.. contents::\n   :depth: 3\n..\n\n+-------------+----------------------------------------------------------------------------------+\n| docs        | |Documentation Status| |image2|                                                  |\n+=============+==================================================================================+\n| tests       | |GitHub Actions| |Coverage Status|                                               |\n|             |                                                                                  |\n|             | |Codacy Code Quality Status| |Scrutinizer Status| |CodeClimate Quality Status|   |\n+-------------+----------------------------------------------------------------------------------+\n| package     | |Supported versions| |Supported implementations| |PyPI Wheel|                    |\n|             |                                                                                  |\n|             | |PyPI Package latest release| |GitHub Releases| |Development Status| |Downloads| |\n|             |                                                                                  |\n|             | |Commits since latest release| |License|                                         |\n+-------------+----------------------------------------------------------------------------------+\n| conda-forge | |Conda Recipe| |Conda Downloads| |Conda Version| |Conda Platforms|               |\n+-------------+----------------------------------------------------------------------------------+\n\nIntroduction\n============\n\nHere is some convenience functions for Cosmology-related analysis.\n\n.. |Documentation Status| image:: https://readthedocs.org/projects/python-coscon/badge/?version=latest\n   :target: https://python-coscon.readthedocs.io/en/latest/?badge=latest&style=plastic\n.. |image1| image:: https://github.com/ickc/python-coscon/workflows/GitHub%20Pages/badge.svg\n   :target: https://ickc.github.io/python-coscon\n.. |GitHub Actions| image:: https://github.com/ickc/python-coscon/workflows/Python%20package/badge.svg\n.. |Coverage Status| image:: https://codecov.io/gh/ickc/python-coscon/branch/master/graphs/badge.svg?branch=master\n   :target: https://codecov.io/github/ickc/python-coscon\n.. |Codacy Code Quality Status| image:: https://img.shields.io/codacy/grade/078ebc537c5747f68c1d4ad3d3594bbf.svg\n   :target: https://www.codacy.com/app/ickc/python-coscon\n.. |Scrutinizer Status| image:: https://img.shields.io/scrutinizer/quality/g/ickc/python-coscon/master.svg\n   :target: https://scrutinizer-ci.com/g/ickc/python-coscon/\n.. |CodeClimate Quality Status| image:: https://codeclimate.com/github/ickc/python-coscon/badges/gpa.svg\n   :target: https://codeclimate.com/github/ickc/python-coscon\n.. |Supported versions| image:: https://img.shields.io/pypi/pyversions/python-coscon.svg\n   :target: https://pypi.org/project/python-coscon\n.. |Supported implementations| image:: https://img.shields.io/pypi/implementation/python-coscon.svg\n   :target: https://pypi.org/project/python-coscon\n.. |PyPI Wheel| image:: https://img.shields.io/pypi/wheel/python-coscon.svg\n   :target: https://pypi.org/project/python-coscon\n.. |PyPI Package latest release| image:: https://img.shields.io/pypi/v/python-coscon.svg\n   :target: https://pypi.org/project/python-coscon\n.. |GitHub Releases| image:: https://img.shields.io/github/tag/ickc/python-coscon.svg?label=github+release\n   :target: https://github.com/ickc/python-coscon/releases\n.. |Development Status| image:: https://img.shields.io/pypi/status/python-coscon.svg\n   :target: https://pypi.python.org/pypi/python-coscon/\n.. |Downloads| image:: https://img.shields.io/pypi/dm/python-coscon.svg\n   :target: https://pypi.python.org/pypi/python-coscon/\n.. |Commits since latest release| image:: https://img.shields.io/github/commits-since/ickc/python-coscon/v0.13.4.svg\n   :target: https://github.com/ickc/python-coscon/compare/v0.13.4...master\n.. |License| image:: https://img.shields.io/pypi/l/python-coscon.svg\n.. |Conda Recipe| image:: https://img.shields.io/badge/recipe-python-coscon-green.svg\n   :target: https://anaconda.org/conda-forge/python-coscon\n.. |Conda Downloads| image:: https://img.shields.io/conda/dn/conda-forge/python-coscon.svg\n   :target: https://anaconda.org/conda-forge/python-coscon\n.. |Conda Version| image:: https://img.shields.io/conda/vn/conda-forge/python-coscon.svg\n   :target: https://anaconda.org/conda-forge/python-coscon\n.. |Conda Platforms| image:: https://img.shields.io/conda/pn/conda-forge/python-coscon.svg\n   :target: https://anaconda.org/conda-forge/python-coscon\n.. |image2| image:: https://github.com/ickc/python-coscon/workflows/GitHub%20Pages/badge.svg\n   :target: https://ickc.github.io/python-coscon\n',
    'author': 'Kolen Cheung',
    'author_email': 'christian.kolen@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ickc/coscon',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8',
}


setup(**setup_kwargs)
